==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/embed/InsertedObjectInfo.hpp <==
#ifndef _COM_SUN_STAR_EMBED_INSERTEDOBJECTINFO_HPP_
#define _COM_SUN_STAR_EMBED_INSERTEDOBJECTINFO_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_EMBED_INSERTEDOBJECTINFO_HDL_
#include "com/sun/star/embed/InsertedObjectInfo.hdl"
#endif

#ifndef _COM_SUN_STAR_BEANS_NAMEDVALUE_HPP_
#include "com/sun/star/beans/NamedValue.hpp"
#endif
#ifndef _COM_SUN_STAR_EMBED_XEMBEDDEDOBJECT_HPP_
#include "com/sun/star/embed/XEmbeddedObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace embed {

inline InsertedObjectInfo::InsertedObjectInfo() SAL_THROW( () )
    : Object()
    , Options()
{
}

inline InsertedObjectInfo::InsertedObjectInfo(const ::com::sun::star::uno::Reference< ::com::sun::star::embed::XEmbeddedObject >& Object_, const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& Options_) SAL_THROW( () )
    : Object(Object_)
    , Options(Options_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::embed::InsertedObjectInfo const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.embed.InsertedObjectInfo");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_EMBED_INSERTEDOBJECTINFO_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/embed/InsertedObjectInfo.hpp <==
#ifndef _COM_SUN_STAR_EMBED_INSERTEDOBJECTINFO_HPP_
#define _COM_SUN_STAR_EMBED_INSERTEDOBJECTINFO_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_EMBED_INSERTEDOBJECTINFO_HDL_
#include "com/sun/star/embed/InsertedObjectInfo.hdl"
#endif

#ifndef _COM_SUN_STAR_BEANS_NAMEDVALUE_HPP_
#include "com/sun/star/beans/NamedValue.hpp"
#endif
#ifndef _COM_SUN_STAR_EMBED_XEMBEDDEDOBJECT_HPP_
#include "com/sun/star/embed/XEmbeddedObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace embed {

inline InsertedObjectInfo::InsertedObjectInfo() SAL_THROW( () )
    : Object()
    , Options()
{
}

inline InsertedObjectInfo::InsertedObjectInfo(const ::com::sun::star::uno::Reference< ::com::sun::star::embed::XEmbeddedObject >& Object_, const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& Options_) SAL_THROW( () )
    : Object(Object_)
    , Options(Options_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace embed {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::embed::InsertedObjectInfo const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.embed.InsertedObjectInfo");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::embed::InsertedObjectInfo const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::embed::InsertedObjectInfo >::get();
}

#endif // _COM_SUN_STAR_EMBED_INSERTEDOBJECTINFO_HPP_
